==> huaweicloudsdkworkspace-3.1.87-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/list_login_records_new_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListLoginRecordsNewResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total_count': 'int',
        'records': 'list[Record]'
    }

    attribute_map = {
        'total_count': 'total_count',
        'records': 'records'
    }

    def __init__(self, total_count=None, records=None):
        """ListLoginRecordsNewResponse

        The model defined in huaweicloud sdk

        :param total_count: 用户登录记录总数。
        :type total_count: int
        :param records: 用户登录记录。
        :type records: list[:class:`huaweicloudsdkworkspace.v2.Record`]
        """
        
        super(ListLoginRecordsNewResponse, self).__init__()

        self._total_count = None
        self._records = None
        self.discriminator = None

        if total_count is not None:
            self.total_count = total_count
        if records is not None:
            self.records = records

    @property
    def total_count(self):
        """Gets the total_count of this ListLoginRecordsNewResponse.

        用户登录记录总数。

        :return: The total_count of this ListLoginRecordsNewResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this ListLoginRecordsNewResponse.

        用户登录记录总数。

        :param total_count: The total_count of this ListLoginRecordsNewResponse.
        :type total_count: int
        """
        self._total_count = total_count

    @property
    def records(self):
        """Gets the records of this ListLoginRecordsNewResponse.

        用户登录记录。

        :return: The records of this ListLoginRecordsNewResponse.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.Record`]
        """
        return self._records

    @records.setter
    def records(self, records):
        """Sets the records of this ListLoginRecordsNewResponse.

        用户登录记录。

        :param records: The records of this ListLoginRecordsNewResponse.
        :type records: list[:class:`huaweicloudsdkworkspace.v2.Record`]
        """
        self._records = records

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListLoginRecordsNewResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/list_login_records_new_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListLoginRecordsNewResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'total_count': 'int',
        'records': 'list[Record]'
    }

    attribute_map = {
        'total_count': 'total_count',
        'records': 'records'
    }

    def __init__(self, total_count=None, records=None):
        r"""ListLoginRecordsNewResponse

        The model defined in huaweicloud sdk

        :param total_count: 用户登录记录总数。
        :type total_count: int
        :param records: 用户登录记录。
        :type records: list[:class:`huaweicloudsdkworkspace.v2.Record`]
        """
        
        super(ListLoginRecordsNewResponse, self).__init__()

        self._total_count = None
        self._records = None
        self.discriminator = None

        if total_count is not None:
            self.total_count = total_count
        if records is not None:
            self.records = records

    @property
    def total_count(self):
        r"""Gets the total_count of this ListLoginRecordsNewResponse.

        用户登录记录总数。

        :return: The total_count of this ListLoginRecordsNewResponse.
        :rtype: int
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        r"""Sets the total_count of this ListLoginRecordsNewResponse.

        用户登录记录总数。

        :param total_count: The total_count of this ListLoginRecordsNewResponse.
        :type total_count: int
        """
        self._total_count = total_count

    @property
    def records(self):
        r"""Gets the records of this ListLoginRecordsNewResponse.

        用户登录记录。

        :return: The records of this ListLoginRecordsNewResponse.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.Record`]
        """
        return self._records

    @records.setter
    def records(self, records):
        r"""Sets the records of this ListLoginRecordsNewResponse.

        用户登录记录。

        :param records: The records of this ListLoginRecordsNewResponse.
        :type records: list[:class:`huaweicloudsdkworkspace.v2.Record`]
        """
        self._records = records

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListLoginRecordsNewResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
